@@ -71,6 +71,14 @@ pub enum Linkage {
     Internal,
 }
 
+/// Visibility
+#[derive(Debug, Clone, Copy)]
+pub enum Visibility {
+    Public,
+    Protected,
+    Private,
+}
+
 /// A function declaration, with a signature, arguments, and argument names.
 ///
 /// The argument names vector must be the same length as the ones in the
@@ -97,6 +105,9 @@ pub struct Function {
 
     /// C++ special member kind, if any.
     special_member: Option<SpecialMemberKind>,
+
+    /// C++ visibility
+    visibility: Visibility,
 }
 
 impl Function {
@@ -109,6 +120,7 @@ impl Function {
         kind: FunctionKind,
         linkage: Linkage,
         special_member: Option<SpecialMemberKind>,
+        visibility: Visibility,
     ) -> Self {
         Function {
             name,
@@ -118,6 +130,7 @@ impl Function {
             kind,
             linkage,
             special_member,
+            visibility,
         }
     }
 
@@ -150,6 +163,11 @@ impl Function {
     pub fn special_member(&self) -> Option<SpecialMemberKind> {
         self.special_member
     }
+
+    /// Whether it is private
+    pub fn visibility(&self) -> Visibility {
+        self.visibility
+    }
 }
 
 impl DotAttributes for Function {
@@ -603,9 +621,13 @@ impl ClangSubItemParser for Function {
             return Err(ParseError::Continue);
         }
 
-        if cursor.access_specifier() == CX_CXXPrivate {
-            return Err(ParseError::Continue);
-        }
+        let visibility = if cursor.access_specifier() == CX_CXXPrivate {
+            Visibility::Private
+        } else if cursor.access_specifier() == CX_CXXProtected {
+            Visibility::Protected
+        } else {
+            Visibility::Public
+        };
 
         if cursor.is_inlined_function() {
             if !context.options().generate_inline_functions {
@@ -666,6 +688,7 @@ impl ClangSubItemParser for Function {
             kind,
             linkage,
             special_member,
+            visibility,
         );
         Ok(ParseResult::New(function, Some(cursor)))
     }
